@@ -5,14 +5,13 @@ use vars qw(@ISA $VERSION);
 
 require LWP::MemberMixin;
 @ISA = qw(LWP::MemberMixin);
-$VERSION = "5.821";
+$VERSION = "5.822";
 
 use HTTP::Request ();
 use HTTP::Response ();
 use HTTP::Date ();
 
 use LWP ();
-use LWP::Debug ();
 use LWP::Protocol ();
 
 use Carp ();
@@ -35,7 +34,6 @@ sub new
         if ref($_[1]) eq 'HASH'; 
 
     my($class, %cnf) = @_;
-    LWP::Debug::trace('()');
 
     my $agent = delete $cnf{agent};
     my $from  = delete $cnf{from};
@@ -119,8 +117,6 @@ sub send_request
 
     local($SIG{__DIE__});  # protect against user defined die handlers
 
-    LWP::Debug::trace("$method $url");
-
     $self->progress("begin", $request);
 
     my $response = $self->run_handlers("request_send", $request);
@@ -134,23 +130,17 @@ sub send_request
             my $x;
             if($x = $self->protocols_allowed) {
                 if (grep lc($_) eq $scheme, @$x) {
-                    LWP::Debug::trace("$scheme URLs are among $self\'s allowed protocols (@$x)");
                 }
                 else {
-                    LWP::Debug::trace("$scheme URLs aren't among $self\'s allowed protocols (@$x)");
                     require LWP::Protocol::nogo;
                     $protocol = LWP::Protocol::nogo->new;
                 }
             }
             elsif ($x = $self->protocols_forbidden) {
                 if(grep lc($_) eq $scheme, @$x) {
-                    LWP::Debug::trace("$scheme URLs are among $self\'s forbidden protocols (@$x)");
                     require LWP::Protocol::nogo;
                     $protocol = LWP::Protocol::nogo->new;
                 }
-                else {
-                    LWP::Debug::trace("$scheme URLs aren't among $self\'s forbidden protocols (@$x)");
-                }
             }
             # else fall thru and create the protocol object normally
         }
@@ -270,8 +260,6 @@ sub request
 {
     my($self, $request, $arg, $size, $previous) = @_;
 
-    LWP::Debug::trace('()');
-
     my $response = $self->simple_request($request, $arg, $size);
 
     if ($previous) {
@@ -294,11 +282,7 @@ sub request
         return $self->request($req, $arg, $size, $response);
     }
 
-
     my $code = $response->code;
-    LWP::Debug::debug('Simple response: ' .
-		      (HTTP::Status::status_message($code) ||
-		       "Unknown code $code"));
 
     if ($code == &HTTP::Status::RC_MOVED_PERMANENTLY or
 	$code == &HTTP::Status::RC_FOUND or
@@ -315,7 +299,7 @@ sub request
 	    $referral->url->scheme eq 'http')
 	{
 	    # RFC 2616, section 15.1.3.
-	    LWP::Debug::trace("https -> http redirect, suppressing Referer");
+	    # https -> http redirect, suppressing Referer
 	    $referral->remove_header('Referer');
 	}
 
@@ -843,7 +827,6 @@ sub mirror
 {
     my($self, $url, $file) = @_;
 
-    LWP::Debug::trace('()');
     my $request = HTTP::Request->new('GET', $url);
 
     if (-e $file) {
@@ -921,8 +904,10 @@ sub proxy
     my $old = $self->{'proxy'}{$key};
     if (@_) {
         my $url = shift;
-        Carp::croak("Proxy must be specified as absolute URI; '$url' is not") unless $url =~ /^$URI::scheme_re:/;
-        Carp::croak("Bad http proxy specification '$url'") if $url =~ /^https?:/ && $url !~ m,^https?://\w,;
+        if (defined($url) && length($url)) {
+            Carp::croak("Proxy must be specified as absolute URI; '$url' is not") unless $url =~ /^$URI::scheme_re:/;
+            Carp::croak("Bad http proxy specification '$url'") if $url =~ /^https?:/ && $url !~ m,^https?://\w,;
+        }
         $self->{proxy}{$key} = $url;
         $self->set_my_handler("request_preprepare", \&_need_proxy)
     }
